==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/af.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "Unknown user" : "Onbekende gebruiker",
    "New comment …" : "Nuwe kommentaar…",
    "Delete comment" : "Skrap kommentaar",
    "Post" : "Plaas",
    "Cancel" : "Kanselleer",
    "Edit comment" : "Wysig kommentaar",
    "[Deleted user]" : "[Geskrapte gebruiker]",
    "No comments yet, start the conversation!" : "Nog geen kommentaar, begin die gesprek!",
    "More comments …" : "Nog kommentare …",
    "Save" : "Bewaar",
    "Allowed characters {count} of {max}" : "Toegelate karakters {telling} van {maks}",
    "Error occurred while retrieving comment with id {id}" : "’n Fout het voorgekom toe kommentaar met id {id} opgehaal is",
    "Error occurred while updating comment with id {id}" : "’n Fout het voorgekom toe kommentaar met id {id} bygewerk is",
    "Error occurred while posting comment" : "’n Fout het voorgekom toe kommentaar geplaas is",
    "_%n unread comment_::_%n unread comments_" : ["%n ongeleesde kommentaar","%n ongeleeste kommentare"],
    "Comment" : "Kommentaar",
    "You commented" : "U het kommentaar gelewer",
    "%1$s commented" : "%1$s het kommentaar gelewer",
    "{author} commented" : "{outeur} het kommentaar gelewer",
    "You commented on %1$s" : "U het op %1$s kommentaar gelewer",
    "You commented on {file}" : "U het op {lêer} kommentaar gelewer",
    "%1$s commented on %2$s" : "%1$s het op %2$s kommentaar gelewer",
    "{author} commented on {file}" : "{outeur} het op {lêer} kommentaar gelewer",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> vir lêers",
    "A (now) deleted user mentioned you in a comment on “%s”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “%s” genoem",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “{lêer}” genoem",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s het u in ’n kommentaar op “%2$s” genoem",
    "{user} mentioned you in a comment on “{file}”" : "{gebruiker} het u in ’n kommentaar oor “{lêer}” genoem"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/af.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "Unknown user" : "Onbekende gebruiker",
    "New comment …" : "Nuwe kommentaar…",
    "Delete comment" : "Skrap kommentaar",
    "Post" : "Plaas",
    "Cancel" : "Kanselleer",
    "Edit comment" : "Wysig kommentaar",
    "[Deleted user]" : "[Geskrapte gebruiker]",
    "No comments yet, start the conversation!" : "Nog geen kommentaar, begin die gesprek!",
    "More comments …" : "Nog kommentare …",
    "Save" : "Bewaar",
    "Allowed characters {count} of {max}" : "Toegelate karakters {telling} van {maks}",
    "Error occurred while retrieving comment with id {id}" : "’n Fout het voorgekom toe kommentaar met id {id} opgehaal is",
    "Error occurred while updating comment with id {id}" : "’n Fout het voorgekom toe kommentaar met id {id} bygewerk is",
    "Error occurred while posting comment" : "’n Fout het voorgekom toe kommentaar geplaas is",
    "_%n unread comment_::_%n unread comments_" : ["%n ongeleesde kommentaar","%n ongeleeste kommentare"],
    "Comment" : "Kommentaar",
    "You commented" : "U het kommentaar gelewer",
    "%1$s commented" : "%1$s het kommentaar gelewer",
    "{author} commented" : "{outeur} het kommentaar gelewer",
    "You commented on %1$s" : "U het op %1$s kommentaar gelewer",
    "You commented on {file}" : "U het op {lêer} kommentaar gelewer",
    "%1$s commented on %2$s" : "%1$s het op %2$s kommentaar gelewer",
    "{author} commented on {file}" : "{outeur} het op {lêer} kommentaar gelewer",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> vir lêers",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s het u in ’n kommentaar op “%2$s” genoem",
    "{user} mentioned you in a comment on “{file}”" : "{gebruiker} het u in ’n kommentaar oor “{lêer}” genoem",
    "A (now) deleted user mentioned you in a comment on “%s”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “%s” genoem",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “{lêer}” genoem"
},
"nplurals=2; plural=(n != 1);");
